#[non_exhaustive]pub enum ClientCriterion<'a> {
Show 21 variants
Matcher(ClientMatcher),
Not(&'a ClientCriterion<'a>),
All(&'a [ClientCriterion<'a>]),
Any(&'a [ClientCriterion<'a>]),
Exactly(usize, &'a [ClientCriterion<'a>]),
SandboxEngine(&'a str),
SandboxEngineRegex(&'a str),
SandboxAppId(&'a str),
SandboxAppIdRegex(&'a str),
SandboxInstanceId(&'a str),
SandboxInstanceIdRegex(&'a str),
Sandboxed,
Uid(i32),
Pid(i32),
IsXwayland,
Comm(&'a str),
CommRegex(&'a str),
Exe(&'a str),
ExeRegex(&'a str),
Tag(&'a str),
TagRegex(&'a str),
}Expand description
A criterion for matching a client.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Matcher(ClientMatcher)
Matches if the contained matcher matches.
Not(&'a ClientCriterion<'a>)
Matches if the contained criterion does not match.
All(&'a [ClientCriterion<'a>])
Matches if all of the contained criteria match.
Any(&'a [ClientCriterion<'a>])
Matches if any of the contained criteria match.
Exactly(usize, &'a [ClientCriterion<'a>])
Matches if an exact number of the contained criteria match.
SandboxEngine(&'a str)
Matches the engine name of the client’s sandbox verbatim.
SandboxEngineRegex(&'a str)
Matches the engine name of the client’s sandbox with a regular expression.
SandboxAppId(&'a str)
Matches the app id of the client’s sandbox verbatim.
SandboxAppIdRegex(&'a str)
Matches the app id of the client’s sandbox with a regular expression.
SandboxInstanceId(&'a str)
Matches the instance id of the client’s sandbox verbatim.
SandboxInstanceIdRegex(&'a str)
Matches the instance id of the client’s sandbox with a regular expression.
Sandboxed
Matches if the client is sandboxed.
Uid(i32)
Matches the user ID of the client.
Pid(i32)
Matches the process ID of the client.
IsXwayland
Matches if the client is Xwayland.
Comm(&'a str)
Matches the /proc/pid/comm of the client verbatim.
CommRegex(&'a str)
Matches the /proc/pid/comm of the client with a regular expression.
Exe(&'a str)
Matches the /proc/pid/exe of the client verbatim.
ExeRegex(&'a str)
Matches the /proc/pid/exe of the client with a regular expression.
Tag(&'a str)
Matches the tag of the client verbatim.
TagRegex(&'a str)
Matches the tag of the client with a regular expression.
Implementations
Sourceimpl ClientCriterion<'_>
impl ClientCriterion<'_>
Sourcepub fn to_matcher(self) -> ClientMatcher
pub fn to_matcher(self) -> ClientMatcher
Converts the criterion to a matcher.
Sourcepub fn bind<F: FnMut(MatchedClient) + 'static>(self, cb: F)
pub fn bind<F: FnMut(MatchedClient) + 'static>(self, cb: F)
Binds a function to execute when the criterion matches a client.
This leaks the matcher.
Sourcepub fn set_capabilities(self, caps: ClientCapabilities)
pub fn set_capabilities(self, caps: ClientCapabilities)
Sets the capabilities granted to clients matching this matcher.
This leaks the matcher.
Sourcepub fn set_sandbox_bounding_capabilities(self, caps: ClientCapabilities)
pub fn set_sandbox_bounding_capabilities(self, caps: ClientCapabilities)
Sets the upper capability bounds for clients in sandboxes created by this client.
This leaks the matcher.