#[non_exhaustive]pub enum ContainerTarget {
Parent,
Itself,
Auto,
}Expand description
The container that an action operates on.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Parent
The parent container of the window. This is the default.
Itself
The window itself.
The action has no effect if the window is not a container.
Auto
The window itself if it is a container, otherwise its parent container.