#[non_exhaustive]pub enum RelativeAxis {
Major,
Minor,
}Expand description
A planar axis relative to the dimensions of a node.
If the node is exactly as wide as it is high, Major is Axis::Horizontal and
Minor is Axis::Vertical.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Major
The axis along the larger dimension of the node.
Minor
The axis along the smaller dimension of the node.