set_visualize_compositing

Function set_visualize_compositing 

pub fn set_visualize_compositing(visualize: bool)
Sets whether compositing is visualized with an overlay icon in the top left.

Regardless of this setting, the icon is hidden if direct scanout is active. This allows detecting direct scanout.

The default is false.