pub fn toggle_float_above_fullscreen()Expand description
Toggles whether floating windows are shown above fullscreen windows.
The default is false.
pub fn toggle_float_above_fullscreen()Toggles whether floating windows are shown above fullscreen windows.
The default is false.