#[non_exhaustive]pub enum FallbackOutputMode {
Cursor,
Focus,
}Expand description
Defines which output is used when no particular output is specified.
This configures where to place a newly opened window or workspace, what window to focus when a
window is closed, which workspace is moved with Seat::move_to_output, and similar actions.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.