Module scrollmethod

Module scrollmethod 

Constants determining the scroll method of a device.

See the libinput documentation for details.

Structs

ScrollMethod
The scroll method of a device.

Constants

SCROLL_METHOD_EDGE
Send scroll events when a finger moves along the bottom or right edge of a device.
SCROLL_METHOD_NO_SCROLL
Never send scroll events instead of pointer motion events.
SCROLL_METHOD_ON_BUTTON_DOWN
Send scroll events when a button is down and the device moves along a scroll-capable axis.
SCROLL_METHOD_TWO_FINGERS
Send scroll events when two fingers are logically down on the device.