InputDevice

Struct InputDevice 

pub struct InputDevice(pub u64);
An input device.

Tuple Fields

0: u64

Implementations

Source

impl InputDevice

pub fn set_seat(self, seat: Seat)

Assigns the input device to a seat.

pub fn set_keymap(self, keymap: Keymap)

Sets the keymap of the device.

This overrides the keymap set for the seat. The keymap becomes active when a key on the device is pressed.

Setting the invalid keymap reverts to the seat keymap.

pub fn has_capability(self, cap: Capability) -> bool

Returns whether the device has the specified capability.

pub fn set_left_handed(self, left_handed: bool)

Sets the device to be left handed.

This has the effect of swapping the left and right mouse button. See the libinput documentation for more details.

pub fn set_accel_profile(self, profile: AccelProfile)

Sets the acceleration profile of the device.

This corresponds to the libinput setting of the same name.

pub fn set_accel_speed(self, speed: f64)

Sets the acceleration speed of the device.

This corresponds to the libinput setting of the same name.

pub fn set_transform_matrix(self, matrix: [[f64; 2]; 2])

Sets the transformation matrix of the device.

This is not a libinput setting but a setting of the compositor. It currently affects relative mouse motions in that the matrix is applied to the motion. To reduce the mouse speed to 35%, use the following matrix:

[
    [0.35, 1.0],
    [1.0, 0.35],
]

This might give you better results than using set_accel_profile and set_accel_speed.

pub fn set_calibration_matrix(self, matrix: [[f32; 3]; 2])

Sets the calibration matrix of the device.

This corresponds to the libinput setting of the same name.

pub fn name(self) -> String

Returns the name of the device.

pub fn set_px_per_wheel_scroll(self, px: f64)

Sets how many pixel to scroll per scroll wheel dedent.

Default: 15.0

This setting has no effect on non-wheel input such as touchpads.

Some mouse wheels support high-resolution scrolling without discrete steps. In this case a value proportional to this setting will be used.

pub fn set_px_scroll_multiplier(self, mul: f64)

Sets a multiplier for pixel scroll events.

Default: 1.0

This setting has no effect on scroll events created by a scroll wheel.

pub fn set_tap_enabled(self, enabled: bool)

Sets whether tap-to-click is enabled for this device.

See https://wayland.freedesktop.org/libinput/doc/latest/tapping.html

pub fn set_drag_enabled(self, enabled: bool)

Sets whether tap-and-drag is enabled for this device.

See https://wayland.freedesktop.org/libinput/doc/latest/tapping.html

pub fn set_drag_lock_enabled(self, enabled: bool)

Sets whether drag lock is enabled for this device.

See https://wayland.freedesktop.org/libinput/doc/latest/tapping.html

pub fn set_natural_scrolling_enabled(self, enabled: bool)

Sets whether natural scrolling is enabled for this device.

See https://wayland.freedesktop.org/libinput/doc/latest/scrolling.html

pub fn set_click_method(self, method: ClickMethod)

pub fn set_middle_button_emulation_enabled(self, enabled: bool)

Sets whether middle button emulation is enabled for this device.

See https://wayland.freedesktop.org/libinput/doc/latest/configuration.html#middle-button-emulation

pub fn set_scroll_method(self, method: ScrollMethod)

pub fn set_scroll_button(self, button: InputEventCode)

pub fn set_scroll_button_lock(self, enabled: bool)

Sets whether scroll button locking is enabled for the device.

See https://wayland.freedesktop.org/libinput/doc/latest/scrolling.html

pub fn syspath(self) -> String

Returns the syspath of this device.

E.g. /sys/devices/pci0000:00/0000:00:08.1/0000:14:00.4/usb5/5-1/5-1.1/5-1.1.3/5-1.1.3:1.0.

pub fn devnode(self) -> String

Returns the devnode of this device.

E.g. /dev/input/event7.

pub fn on_switch_event<F: FnMut(SwitchEvent) + 'static>(self, f: F)

Sets a callback that will be run if this device triggers a switch event.

pub fn set_connector(self, connector: Connector)

Maps this input device to a connector.

The connector should be connected.

This should be used for touch screens and graphics tablets.

pub fn remove_mapping(self)

Removes the mapping of this device to a connector.