pub struct Workspace(pub u64);Expand description
A workspace.
Tuple Fields
0: u64Implementations
Sourceimpl Workspace
impl Workspace
Sourcepub fn exists(self) -> bool
pub fn exists(self) -> bool
Returns whether this workspace existed at the time Seat::get_workspace was called.
Sourcepub fn set_capture(self, capture: bool)
pub fn set_capture(self, capture: bool)
Sets whether the workspaces is captured.
The default is determined by set_default_workspace_capture.
Sourcepub fn get_capture(self) -> bool
pub fn get_capture(self) -> bool
Returns whether the workspaces is captured.
Sourcepub fn toggle_capture(self)
pub fn toggle_capture(self)
Toggles whether the workspaces is captured.
Sourcepub fn move_to_output(self, output: Connector)
pub fn move_to_output(self, output: Connector)
Moves this workspace to another output.
This has no effect if the workspace is not currently being shown.
Sourcepub fn window(self) -> Window
pub fn window(self) -> Window
Returns the root container of this workspace.
If no such container exists, Window::exists returns false.
Sourcepub fn connector(self) -> Connector
pub fn connector(self) -> Connector
Returns the connector that contains this workspace.
If no such connector exists, Connector::exists returns false.
Sourcepub fn show(self) -> WorkspaceShowOp
pub fn show(self) -> WorkspaceShowOp
Creates an operation to show this workspace.
Does nothing until WorkspaceShowOp::exec is called.
Sourcepub fn kind(self) -> WorkspaceKind
pub fn kind(self) -> WorkspaceKind
Returns the kind of this workspace.
Sourcepub fn set_initial_connector(self, connector: Option<Connector>)
pub fn set_initial_connector(self, connector: Option<Connector>)
Sets the connector on which this workspace is initially created.
This setting can be overwritten with WorkspaceShowOp::connector. If that
function is not used or the workspace is created via some other mechanism, it will
be created on the connector set via this function, if possible.