WorkspaceShowOp

Struct WorkspaceShowOp 

pub struct WorkspaceShowOp { /* private fields */ }
An operation to show a workspace.

Create this using Workspace::show.

Implementations

Source

impl WorkspaceShowOp

pub fn exec(self)

Runs this operation.

pub fn connector(self, c: Connector) -> Self

The connector on which to show the workspace.

If the workspace does not already exist, it will be shown on this connector. Otherwise, see WorkspaceShowOp::move_to_connector.

By default, this workspace is determined via the WorkspaceShowOp::seat.

pub fn move_to_connector(self, move_to_connector: bool) -> Self

Whether to move the workspace to the target connector if it already exists.

The default is false.

pub fn seat(self, s: Seat) -> Self

The reference seat.

If no connector was explicitly set, this seat will be used to determine the target output.

pub fn fallback_output_mode(self, mode: FallbackOutputMode) -> Self

The fallback output mode to use when the target output is determined via the WorkspaceShowOp::seat.

The default is determined via Seat::set_fallback_output_mode.

pub fn focus(self, focus: bool) -> Self

Whether the workspace should grab the focus of the WorkspaceShowOp::seat.

The default is true.

pub fn toggle(self, toggle: bool) -> Self

Whether this operation should hide the workspace if it is already visible.

This has no effect for normal workspaces.