Module theme

Module theme 

Tools for configuring the look of the compositor.

Modules

colors
Elements of the compositor whose color can be changed.
sized
Elements of the compositor whose size can be changed.

Structs

Color
A color.

Enums

BarPosition

Functions

get_bar_position
Gets the position of the bar.
get_font
Returns the current font.
reset_colors
Resets all colors to their defaults.
reset_font
Resets the fonts to the defaults.
reset_sizes
Resets all sizes to their defaults.
set_bar_font
Sets the font used by the bar.
set_bar_position
Sets the position of the bar.
set_egui_monospace_fonts
Sets the monospace fonts used by egui windows.
set_egui_proportional_fonts
Sets the proportional fonts used by egui windows.
set_font
Sets the font.
set_title_font
Sets the font used by window titles.