ContainerBorders

Enum ContainerBorders 

#[non_exhaustive]
pub enum ContainerBorders { Separators, Full, FullSmart, }

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Separators

Only separators are drawn between children.



Full

A border is drawn around the entire container.



FullSmart

A border is drawn around the entire container, in addition to the separators between children, unless the container has only one child and is the root container of the workspace.