Connector

Struct Connector 

pub struct Connector(pub u64);
A connector that is potentially connected to an output device.

A connector is the part that sticks out of your graphics card. A graphics card usually has many connectors but one few of them are actually connected to a monitor.

Tuple Fields

0: u64

Implementations

Source

impl Connector

pub fn exists(self) -> bool

Returns whether this connector existed at the time get_connector was called.

This only implies existence at the time get_connector was called. Even if this function returns true, the connector might since have disappeared.

pub fn connected(self) -> bool

Returns whether the connector is connected to an output device.

pub fn scale(self) -> f64

Returns the scale of the currently connected monitor.

pub fn set_scale(self, scale: f64)

Sets the scale to use for the currently connected monitor.

pub fn ty(self) -> ConnectorType

Returns the connector type.

pub fn mode(self) -> Mode

Returns the current mode of the connector.

pub fn set_mode(self, width: i32, height: i32, refresh_millihz: Option<u32>)

Tries to set the mode of the connector.

If the refresh rate is not specified, tries to use the first mode with the given width and height.

The default mode is the first mode advertised by the connector. This is usually the native mode.

pub fn modes(self) -> Vec<Mode>

Returns the available modes of the connector.

pub fn width(self) -> i32

Returns the logical width of the connector.

The returned value will be different from mode().width() if the scale is not 1.

pub fn height(self) -> i32

Returns the logical height of the connector.

The returned value will be different from mode().height() if the scale is not 1.

pub fn refresh_rate(self) -> u32

Returns the refresh rate in mhz of the current mode of the connector.

This is a shortcut for mode().refresh_rate().

pub fn position(self) -> (i32, i32)

Retrieves the position of the output in the global compositor space.

pub fn set_position(self, x: i32, y: i32)

Sets the position of the connector in the global compositor space.

x and y must be non-negative and must not exceed a currently unspecified limit. Any reasonable values for x and y should work.

This function allows the connector to overlap with other connectors, however, such configurations are not supported and might result in unexpected behavior.

pub fn set_enabled(self, enabled: bool)

Enables or disables the connector.

By default, all connectors are enabled.

pub fn set_transform(self, transform: Transform)

Sets the transformation to apply to the content of this connector.

pub fn name(self) -> String

pub fn model(self) -> String

pub fn manufacturer(self) -> String

pub fn serial_number(self) -> String

pub fn set_vrr_mode(self, mode: VrrMode)

Sets the VRR mode.

pub fn set_vrr_cursor_hz(self, hz: f64)

Sets the VRR cursor refresh rate.

Limits the rate at which cursors are updated on screen when VRR is active.

Setting this to infinity disables the limiter.

pub fn set_tearing_mode(self, mode: TearingMode)

Sets the tearing mode.

pub fn set_format(self, format: Format)

Sets the format to use for framebuffers.

pub fn set_colors(self, color_space: ColorSpace, eotf: Eotf)

Sets the color space and EOTF of the connector.

By default, the default values are used which usually means sRGB color space with gamma22 EOTF.

If the output supports it, HDR10 can be enabled by setting the color space to BT.2020 and the EOTF to PQ.

Note that some displays might ignore incompatible settings.

pub fn set_blend_space(self, blend_space: BlendSpace)

Sets the space in which blending is performed for this output.

The default is BlendSpace::SRGB

pub fn set_brightness(self, brightness: Option<f64>)

Sets the brightness of the output.

By default or when brightness is None, the brightness depends on the EOTF:

This should only be used with the PQ transfer function. If the default transfer function is used, you should instead calibrate the hardware directly.

When used with the default transfer function, the default brightness is anchored at 80 cd/m^2. That is, setting this to 40 cd/m^2 makes everything appear half as bright as normal and creates 50% HDR headroom.

This has no effect unless the vulkan renderer is used.

pub fn active_workspace(self) -> Workspace

Get the currently visible/active workspace.

If this connector is not connected, or is there no active workspace, returns a workspace whose exists() returns false.

pub fn workspaces(self) -> Vec<Workspace>

Get all workspaces on this connector.

If this connector is not connected, returns an empty list.

pub fn connector_in_direction(self, direction: Direction) -> Connector

Find the closest connector in the given direction.

Uses center-to-center distance calculation and prefers outputs better aligned with the movement axis.

If no connector exists in the given direction, returns a connector whose exists() returns false.

pub fn set_use_native_gamut(self, use_native_gamut: bool)

Configures whether the display primaries are used.

By default, Jay pretends that the display uses sRGB primaries. This is also how most other systems behave. In reality, most displays use a much larger gamut. For example, they advertise that they support 95% of the DCI-P3 gamut. If the display is interpreting colors in their native gamut, then colors will appear more saturated than their specification.

If this is set to true, Jay assumes that the display uses the primaries advertised in its EDID. This might produce more accurate colors while also allowing color-managed applications to use the full gamut of the display.

This setting has no effect when the display is explicitly operating in a wide color space.

The default is false.