pub enum WorkspaceDisplayOrder {
Manual,
Sorted,
}Expand description
How workspaces should be ordered in the UI.
Variants
Manual
Workspaces are not sorted and can be manually dragged.
Sorted
Workspaces are sorted alphabetically and cannot be manually dragged.