pub struct KeymapBuilder<'a> { /* private fields */ }Expand description
A keymap builder.
Implementations
Sourceimpl<'a> KeymapBuilder<'a>
impl<'a> KeymapBuilder<'a>
Sourcepub fn map(self, map: &'a str) -> Self
pub fn map(self, map: &'a str) -> Self
Sets the XKB map to parse.
See parse_keymap for details about the format.
Sourcepub fn names(
self,
rules: Option<&'a str>,
model: Option<&'a str>,
groups: Option<&'a [Group<'a>]>,
options: Option<&'a [&'a str]>,
) -> Self
pub fn names( self, rules: Option<&'a str>, model: Option<&'a str>, groups: Option<&'a [Group<'a>]>, options: Option<&'a [&'a str]>, ) -> Self
Sets the RMLVO names to parse.
See keymap_from_names for details about the format.
Sourcepub fn shortcuts_group(self, group: u32) -> Self
pub fn shortcuts_group(self, group: u32) -> Self
Sets the 0-based group index to use for shortcuts.
By default, the group that is active at the time of the key press is used. For example, if the keymap has two groups, US and RU, and the active group is 1, shortcuts are looked up against the Russian group.
By calling shortcuts_group(0), shortcuts are instead always looked up against
the English group.