pub struct WorkspaceShowOp { /* private fields */ }Expand description
An operation to show a workspace.
Create this using Workspace::show.
Implementations
Sourceimpl WorkspaceShowOp
impl WorkspaceShowOp
Sourcepub fn connector(self, c: Connector) -> Self
pub fn connector(self, c: Connector) -> Self
The connector on which to show the workspace.
If the workspace does not already exist, it will be shown on this connector.
Otherwise, see WorkspaceShowOp::move_to_connector.
By default, this workspace is determined via the WorkspaceShowOp::seat.
Sourcepub fn move_to_connector(self, move_to_connector: bool) -> Self
pub fn move_to_connector(self, move_to_connector: bool) -> Self
Whether to move the workspace to the target connector if it already exists.
The default is false.
Sourcepub fn seat(self, s: Seat) -> Self
pub fn seat(self, s: Seat) -> Self
The reference seat.
If no connector was explicitly set, this seat will be used to determine the target output.
Sourcepub fn fallback_output_mode(self, mode: FallbackOutputMode) -> Self
pub fn fallback_output_mode(self, mode: FallbackOutputMode) -> Self
The fallback output mode to use when the target output is determined via the WorkspaceShowOp::seat.
The default is determined via Seat::set_fallback_output_mode.
Sourcepub fn focus(self, focus: bool) -> Self
pub fn focus(self, focus: bool) -> Self
Whether the workspace should grab the focus of the WorkspaceShowOp::seat.
The default is true.