Tools for configuring the look of the compositor.
Modules
- colors
- Elements of the compositor whose color can be changed.
- sized
- Elements of the compositor whose size can be changed.
Structs
- Color
- A color.
Enums
Functions
- get_
bar_ position - Gets the position of the bar.
- get_
font - Returns the current font.
- reset_
colors - Resets all colors to their defaults.
- reset_
font - Resets the fonts to the defaults.
- reset_
sizes - Resets all sizes to their defaults.
- set_
bar_ font - Sets the font used by the bar.
- set_
bar_ position - Sets the position of the bar.
- set_
egui_ monospace_ fonts - Sets the monospace fonts used by egui windows.
- set_
egui_ proportional_ fonts - Sets the proportional fonts used by egui windows.
- set_
font - Sets the font.
- set_
title_ font - Sets the font used by window titles.