pub fn create_virtual_output(name: &str)Expand description
Creates a virtual output with the given name.
This is a no-op if a virtual output with that name already exists.
The created connector can be accessed with [get_connector_by_name("VO-{name}")].
A newly created connector is initially disabled. When a connector is destroyed and later recreated, its previous state is restored.