Window

Struct Window 

pub struct Window(pub u64);
A toplevel window.

A toplevel window is anything that can be stored within a container tile or within a floating window.

There are currently four types of windows:

  • Containers
  • Placeholders that take the place of a window when it goes fullscreen
  • XDG toplevels
  • X windows

You can find out the type of a window by using the Window::type_ function.

Tuple Fields

0: u64

Implementations

Source

impl Window

pub fn exists(self) -> bool

Returns whether the window exists.

pub fn does_not_exist(self) -> bool

Returns whether the window does not exist.

This is a shorthand for !self.exists().

pub fn client(self) -> Client

Returns the client of the window.

If the window does not have a client, Client::exists return false.

pub fn title(self) -> String

Returns the title of the window.

pub fn type_(self) -> WindowType

Returns the type of the window.

pub fn content_type(self) -> ContentType

Returns the content type of the window.

pub fn id(self) -> String

Returns the identifier of the window.

This is the identifier used in the ext-foreign-toplevel-list-v1 protocol.

pub fn is_visible(self) -> bool

Returns whether this window is visible.

pub fn parent(self) -> Window

Returns the parent of this window.

If this window has no parent, Window::exists returns false.

pub fn children(self) -> Vec<Window>

Returns the children of this window.

Only containers have children.

pub fn move_(self, direction: Direction)

Moves the window in the specified direction.

pub fn mono(self) -> bool

Returns whether the parent-container of the window is in mono-mode.

pub fn set_mono(self, mono: bool)

Sets whether the parent-container of the window is in mono-mode.

pub fn toggle_mono(self)

Toggles whether the parent-container of the window is in mono-mode.

pub fn split(self) -> Axis

Returns the split axis of the parent-container of the window.

pub fn set_split(self, axis: Axis)

Sets the split axis of the parent-container of the window.

pub fn toggle_split(self)

Toggles the split axis of the parent-container of the window.

pub fn create_split(self, axis: Axis)

Creates a new container with the specified split in place of the window.

pub fn close(self)

Requests the window to be closed.

pub fn floating(self) -> bool

Returns whether the window is floating.

pub fn set_floating(self, floating: bool)

Sets whether the window is floating.

pub fn toggle_floating(self)

Toggles whether the window is floating.

You can do the same by double-clicking on the header.

pub fn workspace(self) -> Workspace

Returns the workspace that this window belongs to.

If no such workspace exists, exists returns false for the returned workspace.

pub fn set_workspace(self, workspace: Workspace)

Moves the window to the workspace.

pub fn toggle_fullscreen(self)

Toggles whether the currently focused window is fullscreen.

pub fn fullscreen(self) -> bool

Returns whether the window is fullscreen.

pub fn set_fullscreen(self, fullscreen: bool)

Sets whether the window is fullscreen.

pub fn float_pinned(self) -> bool

Gets whether the window is pinned.

If a floating window is pinned, it will stay visible even when switching to a different workspace.

pub fn set_float_pinned(self, pinned: bool)

Sets whether the window is pinned.

pub fn toggle_float_pinned(self)

Toggles whether the window is pinned.